==> libgnomedb-0.8.193.tar.gz: libgnomedb-0.8.193/libgnomedb/libgnomedb.h <==
/* GNOME DB library
 * Copyright (C) 1999-2002 The GNOME Foundation.
 *
 * AUTHORS:
 * 	Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
 
#if !defined(_LIBGNOME_DB_H_)
#  define _LIBGNOME_DB_H_

#include <libgda/libgda.h>
#include <libgnomedb/gnome-db-browser.h>
#include <libgnomedb/gnome-db-combo.h>
#include <libgnomedb/gnome-db-config.h>
#include <libgnomedb/gnome-db-connection-selector.h>
#include <libgnomedb/gnome-db-control.h>
#include <libgnomedb/gnome-db-control-widget.h>
#include <libgnomedb/gnome-db-data-source-selector.h>
#include <libgnomedb/gnome-db-dsn-config-druid.h>
#include <libgnomedb/gnome-db-dsn-config.h>
#include <libgnomedb/gnome-db-error.h>
#include <libgnomedb/gnome-db-error-dialog.h>
#include <libgnomedb/gnome-db-form.h>
#include <libgnomedb/gnome-db-gray-bar.h>
#include <libgnomedb/gnome-db-grid.h>
#include <libgnomedb/gnome-db-list.h>
#include <libgnomedb/gnome-db-login.h>
#include <libgnomedb/gnome-db-login-dialog.h>
#include <libgnomedb/gnome-db-model.h>
#include <libgnomedb/gnome-db-provider-selector.h>
#include <libgnomedb/gnome-db-report-editor.h>
#include <libgnomedb/gnome-db-sql-editor.h>
#include <libgnomedb/gnome-db-stock.h>
#include <libgnomedb/gnome-db-table-editor.h>
#include <libgnomedb/gnome-db-util.h>
#include <libgnomedb/gnome-db-window.h>

G_BEGIN_DECLS

void gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *args[]);

void gnome_db_main_run (GdaInitFunc init_func, gpointer user_data);
void gnome_db_main_quit (void);

G_END_DECLS

#endif

==> libgnomedb-0.90.0.tar.gz: libgnomedb-0.90.0/libgnomedb/libgnomedb.h <==
/* GNOME DB library
 * Copyright (C) 1999-2002 The GNOME Foundation.
 *
 * AUTHORS:
 * 	Rodrigo Moya <rodrigo@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
 
#if !defined(_LIBGNOME_DB_H_)
#  define _LIBGNOME_DB_H_

#include <libgda/libgda.h>
#include <libgnomedb/gnome-db-combo.h>
#include <libgnomedb/gnome-db-connection-properties.h>
#include <libgnomedb/gnome-db-connection-selector.h>
#include <libgnomedb/gnome-db-dsn-config.h>
#include <libgnomedb/gnome-db-error.h>
#include <libgnomedb/gnome-db-error-dialog.h>
#include <libgnomedb/gnome-db-form.h>
#include <libgnomedb/gnome-db-gray-bar.h>
#include <libgnomedb/gnome-db-grid.h>
#include <libgnomedb/gnome-db-i18n.h>
#include <libgnomedb/gnome-db-list.h>
#include <libgnomedb/gnome-db-model.h>
#include <libgnomedb/gnome-db-provider-selector.h>
#include <libgnomedb/gnome-db-report-editor.h>
#include <libgnomedb/gnome-db-stock.h>
#include <libgnomedb/gnome-db-table-editor.h>
#include <libgnomedb/gnome-db-util.h>
#ifdef BUILD_WITH_GNOME
#include <libgnomedb/gnome-db-browser.h>
#include <libgnomedb/gnome-db-config.h>
#include <libgnomedb/gnome-db-control.h>
#include <libgnomedb/gnome-db-control-widget.h>
#include <libgnomedb/gnome-db-data-source-selector.h>
#include <libgnomedb/gnome-db-dsn-config-druid.h>
#include <libgnomedb/gnome-db-editor.h>
#include <libgnomedb/gnome-db-icon-list.h>
#include <libgnomedb/gnome-db-login.h>
#include <libgnomedb/gnome-db-login-dialog.h>
#include <libgnomedb/gnome-db-window.h>
#endif

G_BEGIN_DECLS

void gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *args[]);

void gnome_db_main_run (GdaInitFunc init_func, gpointer user_data);
void gnome_db_main_quit (void);

G_END_DECLS

#endif
